==> sdlskk-0.1.tar.gz: sdlskk-0.1/testrender.c <==
#include <sdlskk.h>
#include <SDL.h>
#include <SDL_ttf.h>

SDL_Surface* screen;
SDLSKK_Context* context;
SDLSKK_RomKanaRuleTable* table;
SDLSKK_Dictionary* dict;
TTF_Font* font;

SDL_Color white = { 0xFF, 0xFF, 0xFF, 0 };

void init(void)
{
  dict = SDLSKK_Dict_new( "test_jisyo" );
  table = SDLSKK_RomKanaRuleTable_new();
  SDLSKK_RomKanaRuleTable_load( table, "test_rule_table" );
  context = SDLSKK_Context_new( dict, table );

  if( SDL_Init( SDL_INIT_VIDEO ) < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( SDL_Quit );
  if( TTF_Init() < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( TTF_Quit );

  font = TTF_OpenFont( "sample.ttf", 14 );
  if( font == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  
  screen = SDL_SetVideoMode( 640, 480, 16, SDL_SWSURFACE );
  if( screen == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }

  SDL_EnableUNICODE( 1 );
  return;
}


int main(void)
{ 
  char buf[4098];
  SDL_Surface* tmp_surface;
  SDL_Rect rect = { 0, 0, 640, 480 };
  
  init();
  
  for(;;){
    SDL_Event event;
    while( SDL_PollEvent(&event) ){
      switch(event.type){
      case SDL_KEYDOWN:
	if( event.key.keysym.sym == SDLK_ESCAPE )
	  return 0;
	SDLSKK_Context_input_event( context, &event );
	if( event.key.keysym.sym == SDLK_TAB ){
	  SDLSKK_Context_get_display_str( context, buf, sizeof( buf ) );
	  printf( "%s\n", buf );
	}	
	break;
      case SDL_QUIT:
	return 0;
      }
      tmp_surface = SDLSKK_Context_render_text( context, font, white );
      SDL_FillRect( screen, &rect, 0 );
      SDL_BlitSurface( tmp_surface, NULL, screen, NULL );
      SDL_Flip( screen );
      SDL_FreeSurface( tmp_surface );
      SDL_Delay( 50 );      
    }
  }
}

==> sdlskk-0.2.tar.gz: sdlskk-0.2/testrender.c <==
#include <sdlskk.h>
#include <SDL.h>
#include <SDL_ttf.h>

SDL_Surface* screen;
SDLSKK_Context* context;
SDLSKK_RomKanaRuleTable* table;
SDLSKK_Dictionary* dict;
TTF_Font* font;

SDL_Color white = { 0xFF, 0xFF, 0xFF, 0 };

void init(void)
{
  dict = SDLSKK_Dict_new();
  SDLSKK_Dict_load( dict, "test_jisyo", 0 );
  
  table = SDLSKK_RomKanaRuleTable_new( "test_rule_table" );
  context = SDLSKK_Context_new( dict, table );

  if( SDL_Init( SDL_INIT_VIDEO ) < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( SDL_Quit );
  if( TTF_Init() < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( TTF_Quit );

  font = TTF_OpenFont( "sample.ttf", 14 );
  if( font == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  
  screen = SDL_SetVideoMode( 640, 480, 16, SDL_SWSURFACE );
  if( screen == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }

  SDL_EnableUNICODE( 1 );
  SDL_EnableKeyRepeat( SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL );
  return;
}


int main( int argc, char** argv )
{ 
  char buf[4098];
  SDL_Surface* tmp_surface;
  SDL_Rect rect = { 0, 0, 640, 480 };
  
  init();
  
  for(;;){
    SDL_Event event;
    while( SDL_PollEvent(&event) ){
      switch(event.type){
      case SDL_KEYDOWN:
	if( event.key.keysym.sym == SDLK_ESCAPE )
	  return 0;
	SDLSKK_Context_input_event( context, &event );
	if( event.key.keysym.sym == SDLK_TAB ){
	  SDLSKK_Context_get_display_str( context, buf, sizeof( buf ) );
	  printf( "%s\n", buf );
	}	
	break;
      case SDL_QUIT:
	return 0;
      }
      tmp_surface = SDLSKK_Context_render_display_str( context, font, white );
      SDL_FillRect( screen, &rect, 0 );
      SDL_BlitSurface( tmp_surface, NULL, screen, NULL );
      SDL_Flip( screen );
      SDL_FreeSurface( tmp_surface );
      SDL_Delay( 50 );      
    }
  }
}
